<?php
$TRANSLATIONS = array(
"Could not load template" => "ไม่สามารถโหลดแม่แบบ",
"Saved" => "บันทึกแล้ว",
"Reset" => "ตั้งค่าใหม่",
"An error occurred" => "เกิดข้อผิดพลาดบางประการ",
"Sharing email - public link shares (HTML)" => "ใช้งานอีเมลร่วมกัน - กำลังแชร์ลิงค์สาธารณะ (HTML)",
"Sharing email - public link shares (plain text fallback)" => "ใช้งานอีเมลร่วมกัน - กำลังแชร์ลิงค์สาธารณะ (ข้อความธรรมดา)",
"Sharing email (HTML)" => "แชร์อีเมล (HTML)",
"Sharing email (plain text fallback)" => "การแชร์อีเมล์ (ทางเลือกข้อความธรรมดา)",
"Lost password mail" => "ลืมรหัสผ่านอีเมล",
"New user email (HTML)" => "อีเมลของผู้ใช้ใหม่ (HTML)",
"New user email (plain text fallback)" => "อีเมลของผู้ใช้ใหม่ (ทางเลือกข้อความธรรมดา)",
"Activity notification mail" => "อีเมลแจ้งเตือนกิจกรรม",
"Mail Templates" => "แม่แบบอีเมล",
"Theme" => "ธีม",
"Template" => "แม่แบบ",
"Please choose a template" => "กรุณาเลือกแม่แบบ",
"Save" => "บันทึก"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
